--[[--------------------------------------------------------------------
	Broker Instance Difficulty
	Shows the current instance difficulty on your DataBroker display.
	Written by Phanx <addons@phanx.net>
	See the accompanying README file for more information.
	http://www.wowinterface.com/downloads/info-InstanceDifficulty
	http://www.curse.com/addons/wow/broker-instancedifficulty
----------------------------------------------------------------------]]

-- Change the "" to something else (eg. "None") if you want to see text
-- when you're not in a dungeon, raid, or scenario.
local DEFAULT_TEXT = ""

------------------------------------------------------------------------

local isActive, isGuildGroup
local DIFFICULTY = GetLocale() == "deDE" and "Schwierigkeit"
		or GetLocale():match("^es") and "Dificultad"
		or GetLocale() == "frFR" and "Difficulté"
		or GetLocale() == "itIT" and "Difficoltà"
		or GetLocale() == "ptBR" and "Dificuldade"
		or GetLocale() == "ruRU" and "Сложность"
		or GetLocale() == "koKR" and "난이도"
		or GetLocale() == "zhCN" and "难度"
		or GetLocale() == "zhTW" and "難度"
		or "Difficulty"

local obj = LibStub("LibDataBroker-1.1"):NewDataObject("InstanceDifficulty", {
	type = "data source",
	icon = "Interface\\ICONS\\PVECurrency-Valor",
	label = DIFFICULTY,
	text = DEFAULT_TEXT,
	OnTooltipShow = function(tooltip)
		local instanceName, instanceType, _, difficultyName = GetInstanceInfo()

		local color
		if isGuildGroup then
			color = ChatTypeInfo["GUILD"]
		elseif instanceType == "scenario" then
			color = ChatTypeInfo["INSTANCE_CHAT"]
		else
			color = ChatTypeInfo[strupper(instanceType)] -- matches: party, raid | won't match: none, pvp, scenario
		end

		if color and difficultyName then
			tooltip:AddLine(instanceName, 1, 0.82, 0)
			tooltip:AddLine(difficultyName, 1, 1, 1)
			if isGuildGroup then
				tooltip:AddLine(GUILD, 1, 1, 1)
			end
		else
			tooltip:AddLine(DIFFICULTY, 1, 0.82, 0)
			tooltip:AddLine(NONE, 0.64, 0.64, 0.64)
		end
		tooltip:Show()
	end,
})

local f = CreateFrame("Frame")
f:RegisterEvent("GROUP_ROSTER_UPDATE")
f:RegisterEvent("GUILD_PARTY_STATE_UPDATED")
f:RegisterEvent("PARTY_MEMBER_DISABLE")
f:RegisterEvent("PARTY_MEMBER_ENABLE")
f:RegisterEvent("PLAYER_DIFFICULTY_CHANGED")
f:RegisterEvent("PLAYER_GUILD_UPDATE")
f:RegisterEvent("UPDATE_INSTANCE_INFO")
f:SetScript("OnEvent", function(self, event, ...)
	if event == "GUILD_PARTY_STATE_UPDATED" then
		isGuildGroup = ...
	elseif event ~= "UPDATE_INSTANCE_INFO" then
		RequestGuildPartyState()
	end

	local _, instanceType, difficulty, _, maxPlayers = GetInstanceInfo()
	local _, _, isHeroic, isChallengeMode = GetDifficultyInfo(difficulty)

	local color
	if isGuildGroup then
		color = ChatTypeInfo["GUILD"]
	elseif instanceType == "scenario" then
		color = ChatTypeInfo["INSTANCE_CHAT"]
	else
		color = ChatTypeInfo[strupper(instanceType)] -- matches: party, raid | won't match: none, pvp, scenario
	end

	if color and maxPlayers > 0 then
		obj.text = format("|cff%02x%02x%02x%s%d|r", color.r * 255, color.g * 255, color.b * 255,
			isChallengeMode and "C" or isHeroic and "H" or "N", maxPlayers)
	else
		obj.text = DEFAULT_TEXT
	end
end)